@@ -1,6 +1,7 @@
 import argparse
 from enum import Enum
 from genericpath import isfile
+from runpy import run_path
 from arkitekt.cli.dev.autoreload import watch_directory_and_restart
 from fakts import Fakts
 from fakts.beacon.beacon import FaktsEndpoint
@@ -22,6 +23,7 @@ class ArkitektOptions(str, Enum):
     DEV = "dev"
     LOGOUT = "logout"
     LOGIN = "login"
+    RUN = "run"
 
 
 agent_script = f'''
@@ -52,9 +54,10 @@ mikro_script = """
 from mikro import gql
 
 x = gql('''
-myrepresentations {
+query { myrepresentations {
     id
 }
+}
 ''')
 
 """
@@ -87,8 +90,6 @@ def main(
 
     if script == ArkitektOptions.DEV:
 
-        import runpy
-
         if not os.path.isfile(run_script_path):
             console.print(f"Could't find a run.py in {app_directory} {run_script_path}")
             return
@@ -98,6 +99,17 @@ def main(
 
         asyncio.run(watch_directory_and_restart(app_directory, run_script_path))
 
+    if script == ArkitektOptions.RUN:
+
+        if not os.path.isfile(run_script_path):
+            console.print(f"Could't find a run.py in {app_directory} {run_script_path}")
+            return
+        if not os.path.isfile(fakts_path):
+            console.print(f"{app_directory} does not have a valid fakts.yaml")
+            return
+
+        run_path(run_script_path)
+
     if script == ArkitektOptions.LOGIN:
 
         if not os.path.isfile(fakts_path):
@@ -175,10 +187,15 @@ def main(
             if scan_network is False and beacon is None:
                 beacon = Prompt.ask(
                     "Give us your local beacon",
-                    default="http://localhost:3000/setupapp",
+                    default="localhost",
+                )
+                fakt_grants.append(
+                    EndpointGrant(
+                        FaktsEndpoint(
+                            url=f"http://{beacon}:3000/setupapp", name="local_beacon"
+                        )
+                    )
                 )
-                if scan_network:
-                    fakt_grants.append(EndpointGrant(url=beacon, name="local_beacon"))
 
             fakts = Fakts(
                 grants=fakt_grants,
