@@ -1,6 +1,11 @@
 from pydantic.main import BaseModel
-from ....messages.types import  PROVIDE, PROVIDE_DONE
-from ....messages.base import MessageDataModel, MessageMetaExtensionsModel, MessageMetaModel, MessageModel
+from ....messages.types import PROVIDE, PROVIDE_DONE
+from ....messages.base import (
+    MessageDataModel,
+    MessageMetaExtensionsModel,
+    MessageMetaModel,
+    MessageModel,
+)
 from typing import List, Optional
 
 
@@ -9,13 +14,16 @@ class MetaExtensionsModel(MessageMetaExtensionsModel):
     progress: Optional[str]
     callback: Optional[str]
 
+
 class MetaModel(MessageMetaModel):
     type: str = PROVIDE_DONE
     extensions: Optional[MetaExtensionsModel]
 
+
 class DataModel(MessageDataModel):
-    pod: Optional[int] #TODO: Maybe not optional
+    debug: bool = False  # Sets the
+
 
 class ProvideDoneMessage(MessageModel):
     data: DataModel
-    meta: MetaModel
\ No newline at end of file
+    meta: MetaModel
