@@ -1,4 +1,4 @@
-from ..log import LogDataModel
+from ..log import LogDataModel, LogLevel
 from enum import Enum
 from pydantic.main import BaseModel
 from ....messages.types import  PROVIDE_LOG
@@ -18,4 +18,11 @@ class MetaModel(MessageMetaModel):
 
 class ProvideLogMessage(MessageModel):
     data: LogDataModel
-    meta: MetaModel
\ No newline at end of file
+    meta: MetaModel
+
+    @classmethod
+    def from_log(cls, reference,  message, loglevel = LogLevel.INFO, extensions={}):
+        return cls(data={
+            "level": loglevel,
+            "message": message
+            }, meta={"extensions": extensions, "reference": reference})
\ No newline at end of file
