@@ -1,3 +1,4 @@
+import pydantic
 from arkitekt.packers.registry import get_packer_registry
 from arkitekt.packers.models.base import StructureModel
 from herre.access.model import GraphQLModel
@@ -6,6 +7,10 @@ import logging
 logger = logging.getLogger(__name__)
 
 
+
+
+
+
 class GraphQLStructure(GraphQLModel, StructureModel):
     __typename: str
 
@@ -22,14 +27,9 @@ class GraphQLStructure(GraphQLModel, StructureModel):
     @classmethod
     def register_model(cls, meta=None):
         super().register_model(meta=meta)
-        identifier = cls.get_identifier()
-        assert (
-            identifier is not None
-        ), f"Please provide identifier in your Meta class to register the Model {cls.__name__}, overwrite the classmethod get_identifier(), or specifiy register=False if you dont want to register this Model as a Strucutre"
-        logger.debug(f"Registering {cls} as Structure under identifier {identifier}")
-        get_packer_registry().register_structure(
-            cls, overwrite=getattr(meta, "overwrite", False)
-        )
+        logger.debug(f"Registering {cls} as Structure under identifier {meta}")
+        get_packer_registry().register_structure(cls)
+        
 
     class Meta:
         abstract = True
