@@ -5,36 +5,35 @@ import logging
 
 logger = logging.getLogger(__name__)
 
+
 class SerializationError(Exception):
     """Serialization Error
 
     Serialization Errors are raised when a Shrinking or Expanding Error
     occurs during a shrinking/expanding event
     """
+
     pass
 
 
-
 class ShrinkingError(SerializationError):
-    """ Shrinking Error
-    
+    """Shrinking Error
+
     Is being rased from a Port Shrink Exception
-    
+
     """
 
+
 class ExpandingError(SerializationError):
-    """ Expanding Error
-    
+    """Expanding Error
+
     Is being rased from a Port Expand Exception
-    
+
     """
 
 
-
-
-
 async def shrink_inputs(node, *args, **kwargs) -> Tuple[List[Any], Dict[str, Any]]:
-    """Shrinks args and kwargs 
+    """Shrinks args and kwargs
 
     Shrinks the inputs according to the Node Definition
 
@@ -49,20 +48,19 @@ async def shrink_inputs(node, *args, **kwargs) -> Tuple[List[Any], Dict[str, Any
         Tuple[List[Any], Dict[str, Any]]: Parsed Args as a List, Parsed Kwargs as a dict
     """
     assert len(node.args) == len(args), "Missmatch in Arg Length"
-    
 
-
-    
     shrinked_args_futures = [port.shrink(arg) for port, arg in zip(node.args, args)]
 
     try:
-        shrinked_args = await asyncio.gather(*shrinked_args_futures) # Worrysome because others won't be cancelled on Exception
+        shrinked_args = await asyncio.gather(
+            *shrinked_args_futures
+        )  # Worrysome because others won't be cancelled on Exception
     except Exception as e:
         raise ShrinkingError(f"Couldn't shrink Arguments {args}") from e
 
     try:
         shrinked_kwargs = {
-            port.key: await port.shrink(kwargs.get(port.key, port.default))
+            port.key: await port.shrink(kwargs.get(port.key, None))
             for port in node.kwargs
         }
     except Exception as e:
@@ -70,12 +68,14 @@ async def shrink_inputs(node, *args, **kwargs) -> Tuple[List[Any], Dict[str, Any
         raise ShrinkingError(f"Couldn't shrink KeywordArguments {kwargs}") from e
 
     return shrinked_args, shrinked_kwargs
-    
 
-async def expand_inputs(node, args: List[Any], kwargs: Dict[str, Any]) -> Tuple[List[Any], Dict[str, Any]]:
+
+async def expand_inputs(
+    node, args: List[Any], kwargs: Dict[str, Any]
+) -> Tuple[List[Any], Dict[str, Any]]:
     """Expands Args and Kwargs
 
-    Expands the Args and Kwargs according to the Node definition 
+    Expands the Args and Kwargs according to the Node definition
 
     Args:
         node (Node): Nodes
@@ -99,13 +99,12 @@ async def expand_inputs(node, args: List[Any], kwargs: Dict[str, Any]) -> Tuple[
 
     try:
         expanded_kwargs = {
-            port.key: await port.expand(kwargs.get(port.key, port.default))
+            port.key: await port.expand(kwargs.get(port.key, None))
             for port in node.kwargs
         }
     except Exception as e:
         raise ExpandingError(f"Couldn't expand Kwargs {kwargs}") from e
 
-
     return expanded_args, expanded_kwargs
 
 
@@ -124,10 +123,16 @@ async def shrink_outputs(node, returns) -> List[Any]:
     Returns:
         List[Any]: Parsed Returns
     """
-    if returns is None: returns = ()
-    if not isinstance(returns, tuple): returns = [returns]
-    assert len(node.returns) == len(returns), "Missmatch in Return Length" # We are dealing with a single output, convert it to a proper port like structure
-    shrinked_returns_future = [port.shrink(val) for port, val in zip(node.returns, returns)]
+    if returns is None:
+        returns = ()
+    if not isinstance(returns, tuple):
+        returns = [returns]
+    assert len(node.returns) == len(
+        returns
+    ), "Missmatch in Return Length"  # We are dealing with a single output, convert it to a proper port like structure
+    shrinked_returns_future = [
+        port.shrink(val) for port, val in zip(node.returns, returns)
+    ]
     try:
         return await asyncio.gather(*shrinked_returns_future)
     except Exception as e:
@@ -137,7 +142,7 @@ async def shrink_outputs(node, returns) -> List[Any]:
 async def expand_outputs(node, returns) -> List[Any]:
     """Expands Returns
 
-    Expands the Returns according to the Node definition 
+    Expands the Returns according to the Node definition
 
 
     Args:
@@ -151,12 +156,14 @@ async def expand_outputs(node, returns) -> List[Any]:
         List[Any]: The Expanded Returns
     """
     assert len(node.returns) == len(returns), "Missmatch in Return Length"
-    
-    expanded_returns_future = [port.expand(val) for port, val in zip(node.returns, returns)]
+
+    expanded_returns_future = [
+        port.expand(val) for port, val in zip(node.returns, returns)
+    ]
     try:
         returns = await asyncio.gather(*expanded_returns_future)
-        if len(returns) == 1: 
-            return returns[0] # We are dealing with a single output, just cast back
+        if len(returns) == 1:
+            return returns[0]  # We are dealing with a single output, just cast back
         else:
             return returns
     except Exception as e:
